==> haskell-parsers-0.12.12-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 parsers
version:              0.12.12
visibility:           public
id:                   parsers-0.12.12-6PROTB9MCEOF2XC4sNQYpQ
key:                  parsers-0.12.12-6PROTB9MCEOF2XC4sNQYpQ
license:              BSD-3-Clause
copyright:            Copyright (C) 2010-2013 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/parsers/
synopsis:             Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.

    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".

category:             Text, Parsing
abi:                  a344469b04dc18f3c1f22b807253f84b
exposed:              True
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.Expression
    Text.Parser.LookAhead Text.Parser.Permutation Text.Parser.Token
    Text.Parser.Token.Highlight Text.Parser.Token.Style

import-dirs:          /usr/lib/ghc-9.4.8/site-local/parsers-0.12.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/parsers-0.12.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/parsers-0.12.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-parsers
hs-libraries:         HSparsers-0.12.12-6PROTB9MCEOF2XC4sNQYpQ
depends:
    attoparsec-0.14.4-E6IyHj0fKXuH5r9QvhZ8oW base-4.17.2.1
    binary-0.8.9.1 charset-0.3.12-1tZ82G5IoAhCJ5xuautEgS
    containers-0.6.7 mtl-2.2.2 parsec-3.1.16.1
    scientific-0.3.7.0-43723I2k3fJ8FjtljY7WIm text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-Asw2mvs6LgrELNyeUEam3W

haddock-interfaces:   /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html:         /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parsers-0.12.12-50-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 parsers
version:              0.12.12
visibility:           public
id:                   parsers-0.12.12-56g1Nx5LuKy21C9ziCb1ow
key:                  parsers-0.12.12-56g1Nx5LuKy21C9ziCb1ow
license:              BSD-3-Clause
copyright:            Copyright (C) 2010-2013 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/parsers/
synopsis:             Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.

    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".

category:             Text, Parsing
abi:                  c5991ffc7c536e57ae88dddfa5ab9f30
exposed:              True
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.Expression
    Text.Parser.LookAhead Text.Parser.Permutation Text.Parser.Token
    Text.Parser.Token.Highlight Text.Parser.Token.Style

import-dirs:          /usr/lib/ghc-9.4.8/site-local/parsers-0.12.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/parsers-0.12.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/parsers-0.12.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-parsers
hs-libraries:         HSparsers-0.12.12-56g1Nx5LuKy21C9ziCb1ow
depends:
    attoparsec-0.14.4-Lk9m0Bu4xLu6fNaGof6SYp base-4.17.2.1
    binary-0.8.9.1 charset-0.3.12-CFLbRbplOayLJdF3liT0dS
    containers-0.6.7 mtl-2.2.2 parsec-3.1.16.1
    scientific-0.3.7.0-KrMKCvnfUrQHIZNLkrXCwo text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-2eRdi4Eno3wAApPXuoC33k

haddock-interfaces:   /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html:         /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
